@@ -19,14 +19,15 @@ function post(url, data) {
 	x.setRequestHeader("Content-Type", "application/x-www-form-urlencoded")
 	x.send(data)
 }
-function get(url, whendone, whentimedout) {
+function get(url, whendone, errfunction) {
 	var x = new XMLHttpRequest()
 	x.open("GET", url)
 	x.timeout = 15 * 1000
 	x.responseType = "json"
 	x.onload = function() { whendone(x) }
-	if (whentimedout) {
-		x.ontimeout = function(e) { whentimedout(x, e) }
+	if (errfunction) {
+		x.ontimeout = function(e) { errfunction(" timed out") }
+		x.onerror = function(e) { errfunction(" error") }
 	}
 	x.send()
 }
@@ -131,7 +132,7 @@ function fillinhonks(xhr, glowit) {
 	var holder = honksonpage.children[0]
 	var lenhonks = honks.length
 	for (var i = honks.length; i > 0; i--) {
-		var h = honks[i-1]
+		var h = honks[frontload ? i-1 : 0]
 		if (glowit)
 			h.classList.add("glow")
 		if (frontload) {
@@ -180,10 +181,10 @@ function refreshhonks(btn) {
 		} else {
 			refreshupdate(" status: " + xhr.status)
 		}
-	}, function(xhr, e) {
+	}, function(err) {
 		btn.innerHTML = "refresh"
 		btn.disabled = false
-		refreshupdate(" timed out")
+		refreshupdate(err)
 	})
 }
 function statechanger(evt) {
@@ -229,8 +230,8 @@ function switchtopage(name, arg) {
 			} else {
 				refreshupdate(" status: " + xhr.status)
 			}
-		}, function(xhr, e) {
-			refreshupdate(" timed out")
+		}, function(err) {
+			refreshupdate(err)
 		})
 	}
 	refreshupdate("")
@@ -273,6 +274,16 @@ function relinklinks() {
 		el.onclick = pageswitcher("honker", xid)
 		el.classList.remove("honkerlink")
 	}
+	els = document.getElementsByClassName("donklink")
+	while (els.length) {
+		let el = els[0]
+		el.onclick = function() {
+			el.classList.remove("donk")
+			el.onclick = null
+			return false
+		}
+		el.classList.remove("donklink")
+	}
 
 	els = document.querySelectorAll("#honksonpage article button")
 	els.forEach(function(el) {
@@ -342,6 +353,7 @@ function relinklinks() {
 function showhonkform(elem, rid, hname) {
 	var form = lehonkform
 	form.style = "display: block"
+	form.reset()
 	if (elem) {
 		form.remove()
 		elem.parentElement.parentElement.parentElement.insertAdjacentElement('beforebegin', form)
@@ -350,6 +362,8 @@ function showhonkform(elem, rid, hname) {
 		elem = document.getElementById("honkformhost")
 		elem.insertAdjacentElement('afterend', form)
 	}
+	var donker = document.getElementById("donker")
+	donker.children[1].textContent = ""
 	var ridinput = document.getElementById("ridinput")
 	var honknoise = document.getElementById("honknoise")
 	if (rid) {
@@ -365,6 +379,8 @@ function showhonkform(elem, rid, hname) {
 	}
 	var updateinput = document.getElementById("updatexidinput")
 	updateinput.value = ""
+	var savedfile = document.getElementById("saveddonkxid")
+	savedfile.value = ""
 	honknoise.focus()
 	return false
 }
@@ -445,10 +461,15 @@ function scrollprevioushonk() {
 }
 
 function hotkey(e) {
-	if (e.target instanceof HTMLInputElement || e.target instanceof HTMLTextAreaElement)
-		return
 	if (e.ctrlKey || e.altKey)
 		return
+	if (e.code == "Escape") {
+		var menu = document.getElementById("topmenu")
+		menu.open = false
+		return
+	}
+	if (e.target instanceof HTMLInputElement || e.target instanceof HTMLTextAreaElement)
+		return
 
 	switch (e.code) {
 	case "KeyR":
@@ -465,12 +486,12 @@ function hotkey(e) {
 		break;
 	case "KeyM":
 		var menu = document.getElementById("topmenu")
-		menu.open = true
-		menu.querySelector("a").focus()
-		break
-	case "Escape":
-		var menu = document.getElementById("topmenu")
-		menu.open = false
+		if (!menu.open) {
+			menu.open = true
+			menu.querySelector("a").focus()
+		} else {
+			menu.open = false
+		}
 		break
 	case "Slash":
 		document.getElementById("topmenu").open = true
